@@ -182,11 +182,28 @@ GpgolAddin::GpgolAddin (void) : m_lRef(0),
   m_hook(nullptr),
   m_dispcache(new DispCache)
 {
+  /* Required first to start logging */
   read_options ();
+  TRACEPOINT;
+  /* Start initialization */
+  gpg_err_init ();
+
+  /* Set the installation directory for GpgME so that
+     it can find tools like gpgme-w32-spawn correctly. */
+  char *instdir = get_gpgme_w32_inst_dir();
+  gpgme_set_global_flag ("w32-inst-dir", instdir);
+  xfree (instdir);
+
+  /* The next call initializes subsystems of gpgme and should be
+     done as early as possible.  The actual return value (the
+     version string) is not used here.  It may be called at any
+     time later for this. */
+  gpgme_check_version (NULL);
   /* RibbonExtender is it's own object to avoid the pitfalls of
      multiple inheritance
   */
   m_ribbonExtender = new GpgolRibbonExtender();
+  TRACEPOINT;
 }
 
 GpgolAddin::~GpgolAddin (void)
@@ -381,6 +398,28 @@ GpgolAddin::OnAddInsUpdate (SAFEARRAY** custom)
   return S_OK;
 }
 
+
+/* Note: This is called for each Read event - it may make sense to add
+   some optimization.  */
+void check_auto_vd_mail()
+{
+  /* Check if Mail should automatical be verified/decrypted. */
+  std::string path = "Software\\GNU\\GpgOL\\";
+
+  int val = read_reg_bool (nullptr, path.c_str (), "disableAutoPreview");
+
+  log_debug ("%s:%s: check_vd %s %d",
+             SRCNAME, __func__, path.c_str (),val);
+  if (val == -1)
+    {
+      opt.dont_autodecrypt_preview = 0;
+    }
+  else
+    {
+      opt.dont_autodecrypt_preview = val;
+    }
+}
+
 void
 check_html_preferred()
 {
@@ -698,11 +737,13 @@ GpgolRibbonExtender::GetIDsOfNames (REFIID riid, LPOLESTR *rgszNames,
       ID_MAPPER (L"getIsDetailsEnabled", ID_GET_IS_DETAILS_ENABLED)
       ID_MAPPER (L"getIsAddrBookEnabled", ID_GET_IS_ADDR_BOOK_ENABLED)
       ID_MAPPER (L"getIsCrypto", ID_GET_IS_CRYPTO_MAIL)
+      ID_MAPPER (L"getVdPostponed", ID_GET_VD_POSTPONED)
       ID_MAPPER (L"openContactKey", ID_CMD_OPEN_CONTACT_KEY)
       ID_MAPPER (L"overrideFileClose", ID_CMD_FILE_CLOSE)
       ID_MAPPER (L"overrideFileSaveAs", ID_CMD_FILE_SAVE_AS)
       ID_MAPPER (L"overrideFileSaveAsWindowed", ID_CMD_FILE_SAVE_AS_IN_WINDOW)
       ID_MAPPER (L"decryptPermanently", ID_CMD_DECRYPT_PERMANENTLY)
+      ID_MAPPER (L"decryptManually", ID_CMD_DECRYPT_MANUAL)
     }
 
   if (cNames > 1)
@@ -797,8 +838,12 @@ GpgolRibbonExtender::Invoke (DISPID dispid, REFIID riid, LCID lcid,
           }
       case ID_CMD_DECRYPT_PERMANENTLY:
         return decrypt_permanently (parms->rgvarg[0].pdispVal);
+      case ID_CMD_DECRYPT_MANUAL:
+        return decrypt_manual(parms->rgvarg[0].pdispVal);
       case ID_GET_IS_CRYPTO_MAIL:
         return get_is_crypto_mail (parms->rgvarg[0].pdispVal, result);
+      case ID_GET_VD_POSTPONED:
+        return get_is_vd_postponed (parms->rgvarg[0].pdispVal, result);
       case ID_CMD_OPEN_CONTACT_KEY:
         return open_contact_key (parms->rgvarg[0].pdispVal);
       case ID_CMD_FILE_CLOSE :
@@ -1077,6 +1122,12 @@ GetCustomUI_MIME (BSTR RibbonID, BSTR * RibbonXml)
         "           getImage=\"btnEncryptSmall\""
         "           getVisible=\"getIsCrypto\""
 //"           insertAfterMso=\"FilePrintQuick\""
+        "   />"
+        "   <button id=\"decryptManuallyBtn\""
+        "           label=\"%s\""
+        "           onAction=\"decryptManually\""
+        "           getImage=\"btnEncryptSmall\""
+        "           getVisible=\"getVdPostponed\""
         "   />"
         "  </contextMenu>"
         " </contextMenus>"
@@ -1097,7 +1148,8 @@ GetCustomUI_MIME (BSTR RibbonID, BSTR * RibbonXml)
         _("Sign"), signTTip, signSTip,
         _("Encrypt"), encryptTTip, encryptSTip,
         optsSTip,
-        _("Permanently &amp;decrypt")
+        _("Permanently &amp;decrypt"),
+        _("S&amp;tart decryption")
         );
     }
   else if (!wcscmp (RibbonID, L"Microsoft.Outlook.Explorer"))
