@@ -2055,6 +2055,7 @@ create_category (LPDISPATCH categories, const char *category, int color)
   dispparams.cNamedArgs = 0;
   dispparams.rgvarg = cVariant;
 
+  VariantInit (&rVariant);
   hr = categories->Invoke (dispid, IID_NULL, LOCALE_SYSTEM_DEFAULT,
                            DISPATCH_METHOD, &dispparams,
                            &rVariant, &execpinfo, &argErr);
@@ -3286,8 +3287,8 @@ is_mail_in_folder (LPDISPATCH mailitem, int folder)
 
   bool ret = !strcmp (target_id, folder_id);
 
-  free (target_id);
-  free (folder_id);
+  xfree (target_id);
+  xfree (folder_id);
   TRETURN ret;
 }
 
